<?php declare(strict_types=1);

namespace App\Enums;

use App\Contracts\StorageType\Audio;
use App\Contracts\StorageType\Image;
use App\Contracts\StorageType\Video;

enum StorageType: int implements Image, Video, Audio
{
    case Logo = 1;

    public function getTitle(): string
    {
        return match ($this) {
            self::Logo => __('validation.attributes.logo'),
        };
    }

    public function getAcceptMimes(): array
    {
        return match ($this) {
            self::Logo => ['jpeg', 'jpg', 'png'],
        };
    }

    public function isImage(): bool
    {
        return match ($this) {
            self::Logo => true,
            default => false
        };
    }

    public function isVideo(): bool
    {
        return match ($this->name) {
            default => false
        };
    }

    public function isAudio(): bool
    {
        return match ($this->name) {
            default => false
        };
    }

    public function getFolderName(): string
    {
        return $this->name;
    }
}
