<?php declare(strict_types=1);

namespace App\Http\Middleware;

use App\Enums\CacheTag;
use Closure;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

final class ProjectDomainAndLanguage extends ProjectLanguage
{
    public function handle(Request $request, Closure $next): Response
    {
        $httpHost = $request->getSchemeAndHttpHost();

        $seconds = 3600;
        $project = CacheTag::Project->getCache()->remember(self::class . $httpHost, $seconds, function () use ($httpHost) {
            return $this->projectRepository->getProjectByHttpHost($httpHost) ?? false;
        });
        if ($project === false) {
            $project = null;
        }

        $websiteTranslations = null;
        if ($project !== null) {
            $languageCode = $request->route()?->parameter('language');
            $websiteTranslations = $this->getWebsiteTranslations($project, $languageCode);
            if (\is_null($websiteTranslations)) {
                abort(Response::HTTP_NOT_FOUND);
            }
        }

        unset($request->route()->parameters['language']);
        $request->attributes->set('project', $project);
        $request->attributes->set('websiteTranslations', $websiteTranslations);

        return $next($request);
    }
}
