<?php declare(strict_types=1);

namespace App\Models;

use App\Models\Traits\StorageTrait;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\MorphMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use App\Contracts\Models\Storage as StorageContract;

final class Project extends Model implements StorageContract
{
    use HasFactory, SoftDeletes, StorageTrait;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name',
        'code',
        'http_host',
        'is_public'
    ];

    /**
     * Get the attributes that should be cast.
     *
     * @return array<string, string>
     */
    protected function casts(): array
    {
        return [
            'is_public' => 'boolean',
        ];
    }

    public function roles(): MorphMany
    {
        return $this->morphMany(Role::class, 'morph');
    }

    public function languages(): HasMany
    {
        return $this->hasMany(ProjectLanguage::class);
    }

    public function contents(): HasMany
    {
        return $this->hasMany(ProjectContent::class);
    }

    public function links(): HasMany
    {
        return $this->hasMany(ProjectLink::class);
    }
}
