<?php declare(strict_types=1);

namespace App\View\Components\Volt\Forms;

use Illuminate\Support\Str;
use Illuminate\View\View;

final class TextareaWysiwyg extends Form
{
    public function __construct(
        private readonly string $title,
        private readonly string $name,
        private readonly ?string $value = '',
    ) { }

    protected function getName(): string
    {
        return $this->name;
    }

    private function getTitle(): string
    {
        return Str::ucfirst($this->title);
    }

    private function getValue(): string
    {
        return (string) old($this->getRequestName(), $this->value);
    }

    /**
     * @inheritDoc
     */
    public function render(): View
    {
        $tinymceLicenseKey = config('tinymce.license_key');

        return view('components.volt.forms.textarea-wysiwyg', [
            'tinymceLicenseKey' => $tinymceLicenseKey,
            'title' => $this->getTitle(),
            'name' => $this->getName(),
            'requestName' => $this->getRequestName(),
            'value' => $this->getValue(),
        ]);
    }
}
